@@ -161,17 +161,15 @@ def main():  # noqa: C901
                         metavar='True/False', default=False, type=str2bool,
                         help="""Save intensity distribution
                              (default : %(default)s)""")
-    parser.add_argument('--imputation',
+    parser.add_argument('--extractFeatures',
                         metavar='True/False', default=True, type=str2bool,
-                        help="""Highly recommended method to impute missing
-                            data using data from other days around the same time
-                             (default : %(default)s)""")
+                        help="""Whether to extract signal features. Needed for
+                            activity classification (default : %(default)s)""")
     # activity classification arguments
     parser.add_argument('--activityClassification',
                         metavar='True/False', default=True, type=str2bool,
                         help="""Use pre-trained random forest to predict
-                            activity type
-                            (default : %(default)s)""")
+                            activity type (default : %(default)s)""")
     parser.add_argument('--activityModel', type=str,
                         default="walmsley",
                         help="""trained activity model .tar file""")
@@ -235,6 +233,10 @@ def main():  # noqa: C901
         args.calSlope = [1, 1, 1]
         args.calTemp = [0, 0, 0]
 
+    if args.activityClassification and not args.extractFeatures:
+        args.extractFeatures = True
+        warnings.warn('Setting --extractFeatures True: Required for activity classification')
+
     assert args.sampleRate >= 25, "sampleRate<25 currently not supported"
 
     if args.sampleRate <= 40:
@@ -309,7 +311,7 @@ def main():  # noqa: C901
             rawDataParser=args.rawDataParser, javaHeapSpace=args.javaHeapSpace,
             useFilter=args.useFilter, sampleRate=args.sampleRate, resampleMethod=args.resampleMethod,
             epochPeriod=args.epochPeriod,
-            activityClassification=args.activityClassification,
+            extractFeatures=args.extractFeatures,
             rawOutput=args.rawOutput, rawFile=args.rawFile,
             npyOutput=args.npyOutput, npyFile=args.npyFile,
             startTime=args.startTime, endTime=args.endTime, verbose=args.verbose,
@@ -329,7 +331,6 @@ def main():  # noqa: C901
         stationaryStd=args.stationaryStd, mgCutPointMVPA=args.mgCutPointMVPA,
         mgCutPointVPA=args.mgCutPointVPA, activityModel=args.activityModel,
         intensityDistribution=args.intensityDistribution,
-        imputation=args.imputation,
         psd=args.psd, fourierFrequency=args.fourierFrequency,
         fourierWithAcc=args.fourierWithAcc, m10l5=args.m10l5)
 
